@@ -11,9 +11,7 @@ use base qw( Exporter );
 our @EXPORT_OK = qw( $LOCATOR_AUTO_FROM_COMPLIANT $LOCATOR_AUTO $LOCATOR_GPS $LOCATOR_BASIC );
 our %EXPORT_TAGS = (locator => [@EXPORT_OK]);
 
-our $VERSION = '0.02';
-
-our $DOCOMO_GPS_COMPLIANT_MODELS = qr/(?:903i(?!TV|X)|(?:90[4-6]|SA[78]0[02])i)/;
+our $VERSION = '0.03';
 
 our $LOCATOR_AUTO_FROM_COMPLIANT = 1;
 our $LOCATOR_AUTO                = 2;
@@ -24,7 +22,6 @@ our $LOCATOR_BASIC               = 4;
 sub import {
     my ( $class ) = @_;
     no strict 'refs';
-    *HTTP::MobileAgent::gps_compliant = \&_gps_compliant;
     *HTTP::MobileAgent::locator       = sub { $class->new( @_ ) };
     *HTTP::MobileAgent::get_location  = sub {
         my ( $self, $stuff, $option_ref ) = @_;
@@ -44,20 +41,6 @@ sub new {
 
 sub get_location { die "ABSTRACT METHOD" }
 
-sub _gps_compliant {
-    my $self = shift;
-    if ( $self->is_docomo ) {
-        return $self->model =~ $DOCOMO_GPS_COMPLIANT_MODELS;
-    }
-    elsif ( $self->is_ezweb ) {
-        my @specs = split //, $ENV{ HTTP_X_UP_DEVCAP_MULTIMEDIA } || '';
-        return defined $specs[ 1 ] && $specs[ 1 ] =~ /^[23]$/;
-    }
-    elsif ( $self->is_softbank ) {
-        return $self->is_type_3gc;
-    }
-}
-
 sub _get_carrier_locator {
     my ( $agent, $params, $option_ref ) = @_;
 
